@@ -17,6 +17,7 @@
 
 from __future__ import print_function
 
+import datetime as dt
 import json
 import os
 import webbrowser
@@ -26,12 +27,12 @@ from six.moves import configparser
 from rally.cli import cliutils
 from rally.cli import envutils
 from rally.common import fileutils
-from rally.common.i18n import _
 from rally.common import logging
 from rally.common import yamlutils as yaml
 from rally import exceptions
 from rally import plugins
 
+TIME_FORMAT = "%Y-%m-%dT%H:%M:%S"
 
 LIST_VERIFIERS_HINT = ("HINT: You can list all verifiers, executing "
                        "command `rally verify list-verifiers`.")
@@ -67,17 +68,38 @@ class VerifyCommands(object):
             failure = "\n%s%s\n" % (header, f["traceback"].strip())
             print(failure)
 
-    @cliutils.args("--namespace", dest="namespace", type=str, metavar="<name>",
-                   required=False,
-                   help="Namespace name (for example, openstack).")
-    @plugins.ensure_plugins_are_loaded
-    def list_plugins(self, api, namespace=None):
-        """List all plugins for verifiers management."""
-        if namespace:
-            namespace = namespace.lower()
-        verifier_plugins = api.verifier.list_plugins(namespace)
+    def _print_details_after_run(self, results):
+        failures = [t for t in results["tests"].values()
+                    if t["status"] == "fail"]
+        if failures:
+            h_text = "Failed %d %s - output below:" % (
+                len(failures), "tests" if len(failures) > 1 else "test")
+            self._print_failures(h_text, failures, "=")
+        else:
+            print("\nCongratulations! "
+                  "Verification doesn't have failed tests ;)")
 
-        fields = ["Plugin name", "Namespace", "Description"]
+    @staticmethod
+    def _base_dir(uuid):
+        return os.path.expanduser(
+            "~/.rally/verification/verifier-%s" % uuid)
+
+    def _get_location(self, uuid, loc):
+        return os.path.join(self._base_dir(uuid), loc)
+
+    @cliutils.args("--platform", dest="platform", type=str,
+                   help="Requried patform (e.g. openstack).")
+    @cliutils.deprecated_args("--namespace", dest="platform",
+                              release="0.10.0", alternative="--platform")
+    @plugins.ensure_plugins_are_loaded
+    def list_plugins(self, api, platform=None):
+        """List all plugins for verifiers management."""
+
+        if platform:
+            platform = platform.lower()
+        verifier_plugins = api.verifier.list_plugins(platform=platform)
+
+        fields = ["Plugin name", "Platform", "Description"]
         if logging.is_debug():
             fields.append("Location")
 
@@ -92,11 +114,12 @@ class VerifyCommands(object):
                    help="Verifier plugin name. HINT: You can list all "
                         "verifier plugins, executing command `rally verify "
                         "list-plugins`.")
-    @cliutils.args("--namespace", dest="namespace", type=str, metavar="<name>",
-                   required=False,
-                   help="Verifier plugin namespace. Should be specified in "
+    @cliutils.args("--platform", dest="platform", type=str,
+                   help="Verifier plugin platform. Should be specified in "
                         "case of two verifier plugins with equal names but "
-                        "in different namespaces.")
+                        "in different platforms.")
+    @cliutils.deprecated_args("--namespace", dest="platform",
+                              release="0.10.0", alternative="--platform")
     @cliutils.args("--source", dest="source", type=str, required=False,
                    help="Path or URL to the repo to clone verifier from.")
     @cliutils.args("--version", dest="version", type=str, required=False,
@@ -113,12 +136,13 @@ class VerifyCommands(object):
                    help="Not to set the created verifier as the default "
                         "verifier for future operations.")
     @plugins.ensure_plugins_are_loaded
-    def create_verifier(self, api, name, vtype, namespace="", source=None,
+    def create_verifier(self, api, name, vtype, platform="", source=None,
                         version=None, system_wide=False, extra=None,
                         do_use=True):
         """Create a verifier."""
+
         verifier_uuid = api.verifier.create(
-            name, vtype=vtype, namespace=namespace, source=source,
+            name=name, vtype=vtype, platform=platform, source=source,
             version=version, system_wide=system_wide, extra_settings=extra)
 
         if do_use:
@@ -129,10 +153,11 @@ class VerifyCommands(object):
                    help="Verifier name or UUID. " + LIST_VERIFIERS_HINT)
     def use_verifier(self, api, verifier_id):
         """Choose a verifier to use for the future operations."""
-        verifier = api.verifier.get(verifier_id)
-        fileutils.update_globals_file(envutils.ENV_VERIFIER, verifier.uuid)
-        print(_("Using verifier '%s' (UUID=%s) as the default verifier "
-                "for the future operations.") % (verifier.name, verifier.uuid))
+        verifier = api.verifier.get(verifier_id=verifier_id)
+        fileutils.update_globals_file(envutils.ENV_VERIFIER, verifier["uuid"])
+        print("Using verifier '%s' (UUID=%s) as the default verifier "
+              "for the future CLI operations."
+              % (verifier["name"], verifier["uuid"]))
 
     @cliutils.help_group("verifier")
     @cliutils.args("--status", dest="status", type=str, required=False,
@@ -140,24 +165,25 @@ class VerifyCommands(object):
     @plugins.ensure_plugins_are_loaded
     def list_verifiers(self, api, status=None):
         """List all verifiers."""
-        verifiers = api.verifier.list(status)
+
+        verifiers = api.verifier.list(status=status)
         if verifiers:
-            fields = ["UUID", "Name", "Type", "Namespace", "Created at",
+            fields = ["UUID", "Name", "Type", "Platform", "Created at",
                       "Updated at", "Status", "Version", "System-wide",
                       "Active"]
             cv = envutils.get_global(envutils.ENV_VERIFIER)
             formatters = {
-                "Created at": lambda v: v.created_at.replace(microsecond=0),
-                "Updated at": lambda v: v.updated_at.replace(microsecond=0),
-                "Active": lambda v: u"\u2714" if v.uuid == cv else "",
+                "Created at": lambda v: v["created_at"],
+                "Updated at": lambda v: v["updated_at"],
+                "Active": lambda v: u"\u2714" if v["uuid"] == cv else "",
             }
             cliutils.print_list(verifiers, fields, formatters=formatters,
                                 normalize_field_names=True, sortby_index=4)
         elif status:
-            print(_("There are no verifiers with status '%s'.") % status)
+            print("There are no verifiers with status '%s'." % status)
         else:
-            print(_("There are no verifiers. You can create verifier, using "
-                    "command `rally verify create-verifier`."))
+            print("There are no verifiers. You can create verifier, using "
+                  "command `rally verify create-verifier`.")
 
     @cliutils.help_group("verifier")
     @cliutils.args("--id", dest="verifier_id", type=str,
@@ -166,27 +192,31 @@ class VerifyCommands(object):
     @plugins.ensure_plugins_are_loaded
     def show_verifier(self, api, verifier_id=None):
         """Show detailed information about a verifier."""
-        verifier = api.verifier.get(verifier_id)
+
+        verifier = api.verifier.get(verifier_id=verifier_id)
         fields = ["UUID", "Status", "Created at", "Updated at", "Active",
-                  "Name", "Description", "Type", "Namespace", "Source",
-                  "Version", "System-wide", "Extra settings", "Location"]
+                  "Name", "Description", "Type", "Platform", "Source",
+                  "Version", "System-wide", "Extra settings", "Location",
+                  "Venv location"]
         used_verifier = envutils.get_global(envutils.ENV_VERIFIER)
         formatters = {
-            "Created at": lambda v: v.created_at.replace(microsecond=0),
-            "Updated at": lambda v: v.updated_at.replace(microsecond=0),
-            "Active": lambda v: u"\u2714" if v.uuid == used_verifier else None,
-            "Extra settings": lambda v: (json.dumps(v.extra_settings, indent=4)
-                                         if v.extra_settings else None),
-            "Location": lambda v: v.manager.repo_dir
+            "Created at": lambda v: v["created_at"].replace("T", " "),
+            "Updated at": lambda v: v["updated_at"].replace("T", " "),
+            "Active": lambda v: u"\u2714"
+                                if v["uuid"] == used_verifier else None,
+            "Extra settings": lambda v: (json.dumps(v["extra_settings"],
+                                                    indent=4)
+                                         if v["extra_settings"] else None),
+            "Location": lambda v: self._get_location((v["uuid"]), "repo")
         }
-        if not verifier.system_wide:
-            fields.append("Venv location")
-            formatters["Venv location"] = lambda v: v.manager.venv_dir
+        if not verifier["system_wide"]:
+            formatters["Venv location"] = lambda v: self._get_location(
+                v["uuid"], ".venv")
         cliutils.print_dict(verifier, fields=fields, formatters=formatters,
                             normalize_field_names=True, print_header=False,
                             table_label="Verifier")
-        print(_("Attention! All you do in the verifier repository or "
-                "verifier virtual environment, you do it at your own risk!"))
+        print("Attention! All you do in the verifier repository or verifier "
+              "virtual environment, you do it at your own risk!")
 
     @cliutils.help_group("verifier")
     @cliutils.args("--id", dest="verifier_id", type=str, required=True,
@@ -206,7 +236,10 @@ class VerifyCommands(object):
     @plugins.ensure_plugins_are_loaded
     def delete_verifier(self, api, verifier_id, deployment=None, force=False):
         """Delete a verifier."""
-        api.verifier.delete(verifier_id, deployment, force)
+
+        api.verifier.delete(verifier_id=verifier_id,
+                            deployment_id=deployment,
+                            force=force)
 
     @cliutils.help_group("verifier")
     @cliutils.args("--id", dest="verifier_id", type=str,
@@ -231,14 +264,15 @@ class VerifyCommands(object):
                         system_wide=None, no_system_wide=None,
                         update_venv=None):
         """Update a verifier."""
+
         if not (version or system_wide or no_system_wide or update_venv):
-            print(_("At least one of the following arguments should be "
-                    "provided: '--update-venv', '--version', '--system-wide', "
-                    "'--no-system-wide'."))
+            print("At least one of the following arguments should be "
+                  "provided: '--update-venv', '--version', '--system-wide', "
+                  "'--no-system-wide'.")
             return 1
 
-        msg = _("Arguments '--%s' and '--%s' cannot be used simultaneously. "
-                "You can use only one of the mentioned arguments.")
+        msg = ("Arguments '--%s' and '--%s' cannot be used simultaneously. "
+               "You can use only one of the mentioned arguments.")
         if update_venv and system_wide:
             print(msg % ("update-venv", "system-wide"))
             return 1
@@ -247,12 +281,14 @@ class VerifyCommands(object):
             return 1
 
         system_wide = False if no_system_wide else (system_wide or None)
-        api.verifier.update(verifier_id, system_wide=system_wide,
-                            version=version, update_venv=update_venv)
+        api.verifier.update(verifier_id=verifier_id,
+                            system_wide=system_wide,
+                            version=version,
+                            update_venv=update_venv)
 
-        print(_("HINT: In some cases the verifier config file should be "
-                "updated as well. Use `rally verify configure-verifier` "
-                "command to update the config file."))
+        print("HINT: In some cases the verifier config file should be "
+              "updated as well. Use `rally verify configure-verifier` "
+              "command to update the config file.")
 
     @cliutils.help_group("verifier")
     @cliutils.args("--id", dest="verifier_id", type=str,
@@ -284,21 +320,21 @@ class VerifyCommands(object):
 
         # TODO(ylobankov): Add an ability to read extra options from
         #                  a json or yaml file.
-
         if new_configuration and (extra_options or reconfigure):
-            print(_("Argument '--override' cannot be used with arguments "
-                    "'--reconfigure' and '--extend'."))
+            print("Argument '--override' cannot be used with arguments "
+                  "'--reconfigure' and '--extend'.")
             return 1
 
         if new_configuration:
             if not os.path.exists(new_configuration):
-                print(_("File '%s' not found.") % new_configuration)
+                print("File '%s' not found." % new_configuration)
                 return 1
 
             with open(new_configuration) as f:
                 config = f.read()
-            api.verifier.override_configuration(verifier_id, deployment,
-                                                config)
+            api.verifier.override_configuration(verifier_id=verifier_id,
+                                                deployment_id=deployment,
+                                                new_configuration=config)
         else:
             if extra_options:
                 if os.path.isfile(extra_options):
@@ -315,7 +351,8 @@ class VerifyCommands(object):
                 else:
                     extra_options = yaml.safe_load(extra_options)
 
-            config = api.verifier.configure(verifier_id, deployment,
+            config = api.verifier.configure(verifier=verifier_id,
+                                            deployment_id=deployment,
                                             extra_options=extra_options,
                                             reconfigure=reconfigure)
 
@@ -333,12 +370,14 @@ class VerifyCommands(object):
     @plugins.ensure_plugins_are_loaded
     def list_verifier_tests(self, api, verifier_id=None, pattern=""):
         """List all verifier tests."""
-        tests = api.verifier.list_tests(verifier_id, pattern)
+
+        tests = api.verifier.list_tests(verifier_id=verifier_id,
+                                        pattern=pattern)
         if tests:
             for test in tests:
                 print(test)
         else:
-            print(_("No tests found."))
+            print("No tests found.")
 
     @cliutils.help_group("verifier-ext")
     @cliutils.args("--id", dest="verifier_id", type=str,
@@ -357,8 +396,9 @@ class VerifyCommands(object):
     def add_verifier_ext(self, api, verifier_id=None, source=None,
                          version=None, extra=None):
         """Add a verifier extension."""
-        api.verifier.add_extension(verifier_id, source=source, version=version,
-                                   extra_settings=extra)
+
+        api.verifier.add_extension(verifier_id=verifier_id, source=source,
+                                   version=version, extra_settings=extra)
 
     @cliutils.help_group("verifier-ext")
     @cliutils.args("--id", dest="verifier_id", type=str,
@@ -367,7 +407,8 @@ class VerifyCommands(object):
     @plugins.ensure_plugins_are_loaded
     def list_verifier_exts(self, api, verifier_id=None):
         """List all verifier extensions."""
-        verifier_exts = api.verifier.list_extensions(verifier_id)
+
+        verifier_exts = api.verifier.list_extensions(verifier_id=verifier_id)
         if verifier_exts:
             fields = ["Name", "Entry point"]
             if logging.is_debug():
@@ -375,19 +416,8 @@ class VerifyCommands(object):
             cliutils.print_list(verifier_exts, fields,
                                 normalize_field_names=True)
         else:
-            print(_("There are no verifier extensions. You can add "
-                    "verifier extension, using command `rally verify "
-                    "add-verifier-ext`."))
-
-    def _print_details_after_run(self, results):
-        failures = results.filter_tests("fail").values()
-        if failures:
-            h_text = "Failed %d %s - output below:" % (
-                len(failures), "tests" if len(failures) > 1 else "test")
-            self._print_failures(h_text, failures, "=")
-        else:
-            print(_("\nCongratulations! Verification doesn't have failed "
-                    "tests! :)"))
+            print("There are no verifier extensions. You can add verifier "
+                  "extension, using command `rally verify add-verifier-ext`.")
 
     @cliutils.help_group("verifier-ext")
     @cliutils.args("--id", dest="verifier_id", type=str,
@@ -398,7 +428,8 @@ class VerifyCommands(object):
     @plugins.ensure_plugins_are_loaded
     def delete_verifier_ext(self, api, verifier_id=None, name=None):
         """Delete a verifier extension."""
-        api.verifier.delete_extension(verifier_id, name)
+
+        api.verifier.delete_extension(verifier_id=verifier_id, name=name)
 
     @cliutils.help_group("verification")
     @cliutils.args("--id", dest="verifier_id", type=str,
@@ -445,10 +476,10 @@ class VerifyCommands(object):
               pattern=None, concur=0, load_list=None, skip_list=None,
               xfail_list=None, detailed=False, do_use=True):
         """Start a verification (run verifier tests)."""
+
         if pattern and load_list:
-            print(_("Arguments '--pattern' and '--load-list' cannot be used "
-                    "simultaneously. You can use only one of the mentioned "
-                    "arguments."))
+            print("Arguments '--pattern' and '--load-list' cannot be used "
+                  "together, use only one of them.")
             return 1
 
         def parse(filename):
@@ -457,20 +488,20 @@ class VerifyCommands(object):
 
         if load_list:
             if not os.path.exists(load_list):
-                print(_("File '%s' not found.") % load_list)
+                print("File '%s' not found." % load_list)
                 return 1
             with open(load_list, "r") as f:
                 load_list = [test for test in f.read().split("\n") if test]
 
         if skip_list:
             if not os.path.exists(skip_list):
-                print(_("File '%s' not found.") % skip_list)
+                print("File '%s' not found." % skip_list)
                 return 1
             skip_list = parse(skip_list)
 
         if xfail_list:
             if not os.path.exists(xfail_list):
-                print(_("File '%s' not found.") % xfail_list)
+                print("File '%s' not found." % xfail_list)
                 return 1
             xfail_list = parse(xfail_list)
 
@@ -480,33 +511,37 @@ class VerifyCommands(object):
             ("concurrency", concur)) if value}
 
         try:
-            verification, results = api.verification.start(
-                verifier_id, deployment, tags=tags, **run_args)
+            results = api.verification.start(
+                verifier_id=verifier_id, deployment_id=deployment,
+                tags=tags, **run_args)
+            verification_uuid = results["verification"]["uuid"]
         except exceptions.DeploymentNotFinishedStatus as e:
-            print(_("Cannot start a verefication on "
-                    "unfinished deployment: %s") % e)
+            print("Cannot start a verification against unfinished deployment: "
+                  " %s" % e)
             return 1
 
         if detailed:
             self._print_details_after_run(results)
 
-        self._print_totals(results.totals)
+        self._print_totals(results["totals"])
 
         if do_use:
-            self.use(api, verification.uuid)
+            self.use(api, verification_uuid)
         else:
-            print(_("Verification UUID: %s.") % verification.uuid)
+            print("Verification UUID: %s." % verification_uuid)
 
     @cliutils.help_group("verification")
     @cliutils.args("--uuid", dest="verification_uuid", type=str, required=True,
                    help="Verification UUID. " + LIST_VERIFICATIONS_HINT)
     def use(self, api, verification_uuid):
         """Choose a verification to use for the future operations."""
-        verification = api.verification.get(verification_uuid)
+
+        verification = api.verification.get(
+            verification_uuid=verification_uuid)
         fileutils.update_globals_file(
-            envutils.ENV_VERIFICATION, verification.uuid)
-        print(_("Using verification (UUID=%s) as the default verification "
-                "for the future operations.") % verification.uuid)
+            envutils.ENV_VERIFICATION, verification["uuid"])
+        print("Using verification (UUID=%s) as the default verification "
+              "for the future operations." % verification["uuid"])
 
     @cliutils.help_group("verification")
     @cliutils.args("--uuid", dest="verification_uuid", type=str,
@@ -536,18 +571,21 @@ class VerifyCommands(object):
     def rerun(self, api, verification_uuid=None, deployment=None, tags=None,
               concur=None, failed=False, detailed=False, do_use=True):
         """Rerun tests from a verification for a specific deployment."""
-        verification, results = api.verification.rerun(
-            verification_uuid, deployment_id=deployment, failed=failed,
-            tags=tags, concurrency=concur)
+
+        results = api.verification.rerun(verification_uuid=verification_uuid,
+                                         deployment_id=deployment,
+                                         failed=failed,
+                                         tags=tags,
+                                         concurrency=concur)
         if detailed:
             self._print_details_after_run(results)
 
-        self._print_totals(results.totals)
+        self._print_totals(results["totals"])
 
         if do_use:
-            self.use(api, verification.uuid)
+            self.use(api, results["verification"]["uuid"])
         else:
-            print(_("Verification UUID: %s.") % verification.uuid)
+            print("Verification UUID: %s." % results["verification"]["uuid"])
 
     @cliutils.help_group("verification")
     @cliutils.args("--uuid", dest="verification_uuid", type=str,
@@ -563,13 +601,16 @@ class VerifyCommands(object):
     def show(self, api, verification_uuid=None, sort_by="name",
              detailed=False):
         """Show detailed information about a verification."""
-        verification = api.verification.get(verification_uuid)
-        verifier = api.verifier.get(verification.verifier_uuid)
-        deployment = api.deployment.get(verification.deployment_uuid)
+
+        verification = api.verification.get(
+            verification_uuid=verification_uuid)
+        verifier = api.verifier.get(verifier_id=verification["verifier_uuid"])
+        deployment = api.deployment.get(
+            deployment=verification["deployment_uuid"])
 
         def run_args_formatter(v):
             run_args = []
-            for k in sorted(v.run_args):
+            for k in sorted(v["run_args"]):
                 if k in ("load_list", "skip_list", "xfail_list"):
                     value = "(value is too long, %s)"
                     if detailed:
@@ -577,7 +618,7 @@ class VerifyCommands(object):
                     else:
                         value %= "use 'detailed' flag to display it"
                 else:
-                    value = v.run_args[k]
+                    value = v["run_args"][k]
                 run_args.append("%s: %s" % (k, value))
             return "\n".join(run_args)
 
@@ -588,33 +629,35 @@ class VerifyCommands(object):
                   "Success", "Skipped", "Expected failures",
                   "Unexpected success", "Failures"]
         formatters = {
-            "Started at": lambda v: v.created_at.replace(microsecond=0),
-            "Finished at": lambda v: v.updated_at.replace(microsecond=0),
-            "Duration": lambda v: (v.updated_at.replace(microsecond=0) -
-                                   v.created_at.replace(microsecond=0)),
+            "Started at": lambda v: v["created_at"].replace("T", " "),
+            "Finished at": lambda v: v["updated_at"].replace("T", " "),
+            "Duration": lambda v: (dt.datetime.strptime(v["updated_at"],
+                                                        TIME_FORMAT) -
+                                   dt.datetime.strptime(v["created_at"],
+                                                        TIME_FORMAT)),
             "Run arguments": run_args_formatter,
-            "Tags": lambda v: ", ".join(v.tags) or None,
-            "Verifier name": lambda v: "%s (UUID: %s)" % (verifier.name,
-                                                          verifier.uuid),
+            "Tags": lambda v: ", ".join(v["tags"]) or None,
+            "Verifier name": lambda v: "%s (UUID: %s)" % (verifier["name"],
+                                                          verifier["uuid"]),
             "Verifier type": (
-                lambda v: "%s (namespace: %s)" % (verifier.type,
-                                                  verifier.namespace)),
+                lambda v: "%s (platform: %s)" % (verifier["type"],
+                                                 verifier["platform"])),
             "Deployment name": (
                 lambda v: "%s (UUID: %s)" % (deployment["name"],
                                              deployment["uuid"])),
-            "Tests duration, sec": lambda v: v.tests_duration
+            "Tests duration, sec": lambda v: v["tests_duration"]
         }
         cliutils.print_dict(verification, fields, formatters=formatters,
                             normalize_field_names=True, print_header=False,
                             table_label="Verification")
 
         if detailed:
-            h = _("Run arguments")
+            h = "Run arguments"
             print("\n%s" % cliutils.make_header(h, len(h)).strip())
-            print("\n%s\n" % json.dumps(verification.run_args, indent=4))
+            print("\n%s\n" % json.dumps(verification["run_args"], indent=4))
 
         # Tests table
-        tests = verification.tests
+        tests = verification["tests"]
         values = [tests[test_id] for test_id in tests]
         fields = ["Name", "Duration, sec", "Status"]
         formatters = {"Duration, sec": lambda v: v["duration"]}
@@ -628,8 +671,7 @@ class VerifyCommands(object):
             if failures:
                 self._print_failures("Failures", failures)
             else:
-                print(_("\nCongratulations! Verification doesn't have failed "
-                        "tests! :)"))
+                print("\nCongratulations! Verification passed all tests ;)")
 
     @cliutils.help_group("verification")
     @cliutils.args("--id", dest="verifier_id", type=str, required=False,
@@ -644,30 +686,33 @@ class VerifyCommands(object):
     def list(self, api, verifier_id=None, deployment=None, tags=None,
              status=None):
         """List all verifications."""
-        verifications = api.verification.list(verifier_id, deployment, tags,
-                                              status)
+
+        verifications = api.verification.list(verifier_id=verifier_id,
+                                              deployment_id=deployment,
+                                              tags=tags, status=status)
         if verifications:
             fields = ["UUID", "Tags", "Verifier name", "Deployment name",
                       "Started at", "Finished at", "Duration", "Status"]
             formatters = {
-                "Tags": lambda v: ", ".join(v.tags) or "-",
-                "Verifier name": (
-                    lambda v: api.verifier.get(v.verifier_uuid).name),
-                "Deployment name": (
-                    lambda v: api.deployment.get(v.deployment_uuid)["name"]),
-                "Started at": lambda v: v.created_at.replace(microsecond=0),
-                "Finished at": lambda v: v.updated_at.replace(microsecond=0),
-                "Duration": lambda v: (v.updated_at.replace(microsecond=0) -
-                                       v.created_at.replace(microsecond=0))
+                "Tags": lambda v: ", ".join(v["tags"]) or "-",
+                "Verifier name": (lambda v: api.verifier.get(
+                    verifier_id=v["verifier_uuid"])["name"]),
+                "Deployment name": (lambda v: api.deployment.get(
+                    deployment=v["deployment_uuid"])["name"]),
+                "Started at": lambda v: v["created_at"],
+                "Finished at": lambda v: v["updated_at"],
+                "Duration": lambda v: (dt.datetime.strptime(v["updated_at"],
+                                                            TIME_FORMAT) -
+                                       dt.datetime.strptime(v["created_at"],
+                                                            TIME_FORMAT))
             }
             cliutils.print_list(verifications, fields, formatters=formatters,
                                 normalize_field_names=True, sortby_index=4)
         elif verifier_id or deployment or status or tags:
-            print(_("There are no verifications that meet specified filter "
-                    "arguments."))
+            print("There are no verifications that meet specified criteria.")
         else:
-            print(_("There are no verifications. You can start verification, "
-                    "using command `rally verify start`."))
+            print("There are no verifications. You can start verification, "
+                  "using command `rally verify start`.")
 
     @cliutils.help_group("verification")
     @cliutils.args("--uuid", nargs="+", dest="verification_uuid", type=str,
@@ -675,10 +720,11 @@ class VerifyCommands(object):
                    help="UUIDs of verifications. " + LIST_VERIFICATIONS_HINT)
     def delete(self, api, verification_uuid):
         """Delete a verification or a few verifications."""
+
         if not isinstance(verification_uuid, list):
             verification_uuid = [verification_uuid]
         for v_uuid in verification_uuid:
-            api.verification.delete(v_uuid)
+            api.verification.delete(verification_uuid=v_uuid)
 
     @cliutils.help_group("verification")
     @cliutils.args("--uuid", nargs="+", dest="verification_uuid", type=str,
@@ -701,13 +747,15 @@ class VerifyCommands(object):
     def report(self, api, verification_uuid=None, output_type=None,
                output_dest=None, open_it=None):
         """Generate a report for a verification or a few verifications."""
+
         if not isinstance(verification_uuid, list):
             verification_uuid = [verification_uuid]
 
-        result = api.verification.report(verification_uuid, output_type,
-                                         output_dest)
+        result = api.verification.report(uuids=verification_uuid,
+                                         output_type=output_type,
+                                         output_dest=output_dest)
         if "files" in result:
-            print(_("Saving the report to '%s' file. It may take some time.")
+            print("Saving the report to '%s' file. It may take some time."
                   % output_dest)
             for path in result["files"]:
                 full_path = os.path.abspath(os.path.expanduser(path))
@@ -715,12 +763,12 @@ class VerifyCommands(object):
                     os.makedirs(os.path.dirname(full_path))
                 with open(full_path, "w") as f:
                     f.write(result["files"][path])
-            print(_("The report has been successfully saved."))
+            print("The report has been successfully saved.")
 
             if open_it:
                 if "open" not in result:
-                    print(_("Cannot open '%s' report in the browser because "
-                            "report type doesn't support it.") % output_type)
+                    print("Cannot open '%s' report in the browser because "
+                          "report type doesn't support it." % output_type)
                     return 1
                 webbrowser.open_new_tab(
                     "file://" + os.path.abspath(result["open"]))
@@ -728,7 +776,7 @@ class VerifyCommands(object):
         if "print" in result:
             # NOTE(andreykurilin): we need a separation between logs and
             #   printed information to be able to parse output
-            h = _("Verification Report")
+            h = "Verification Report"
             print("\n%s\n%s" % (cliutils.make_header(h, len(h)),
                                 result["print"]))
 
@@ -754,18 +802,21 @@ class VerifyCommands(object):
     def import_results(self, api, verifier_id=None, deployment=None,
                        file_to_parse=None, run_args=None, do_use=True):
         """Import results of a test run into the Rally database."""
+
         if not os.path.exists(file_to_parse):
-            print(_("File '%s' not found.") % file_to_parse)
+            print("File '%s' not found." % file_to_parse)
             return 1
         with open(file_to_parse, "r") as f:
             data = f.read()
 
         run_args = yaml.safe_load(run_args) if run_args else {}
         verification, results = api.verification.import_results(
-            verifier_id, deployment, data, **run_args)
-        self._print_totals(results.totals)
+            verifier_id=verifier_id, deployment_id=deployment,
+            data=data, **run_args)
+        self._print_totals(results["totals"])
 
+        verification_uuid = verification["uuid"]
         if do_use:
-            self.use(verification.uuid)
+            self.use(api, verification_uuid)
         else:
-            print(_("Verification UUID: %s.") % verification.uuid)
+            print("Verification UUID: %s." % verification_uuid)
