@@ -52,75 +52,12 @@ class DeploymentCommandsTestCase(test.TestCase):
         self.fake_api.deployment.create.assert_called_once_with(
             config={}, name="fake_deploy")
 
-    @mock.patch.dict(os.environ, {"OS_AUTH_URL": "fake_auth_url",
-                                  "OS_USERNAME": "fake_username",
-                                  "OS_PASSWORD": "fake_password",
-                                  "OS_TENANT_NAME": "fake_tenant_name",
-                                  "OS_REGION_NAME": "fake_region_name",
-                                  "OS_ENDPOINT_TYPE": "fake_endpoint_typeURL",
-                                  "OS_ENDPOINT": "fake_endpoint",
-                                  "OS_INSECURE": "True",
-                                  "OS_CACERT": "fake_cacert",
-                                  "RALLY_DEPLOYMENT": "fake_deployment_id",
-                                  "OSPROFILER_HMAC_KEY": "fake_hmac_key"})
-    @mock.patch("rally.cli.commands.deployment.DeploymentCommands.list")
-    def test_createfromenv_keystonev2(self, mock_list):
+    @mock.patch("rally.env.env_mgr.EnvManager.create_spec_from_sys_environ",
+                return_value={"spec": {"auth_url": "http://fake"}})
+    def test_createfromenv(self, mock_create_spec_from_sys_environ):
         self.deployment.create(self.fake_api, "from_env", True)
         self.fake_api.deployment.create.assert_called_once_with(
-            config={
-                "openstack": {
-                    "auth_url": "fake_auth_url",
-                    "region_name": "fake_region_name",
-                    "endpoint_type": "fake_endpoint_type",
-                    "endpoint": "fake_endpoint",
-                    "admin": {
-                        "username": "fake_username",
-                        "password": "fake_password",
-                        "tenant_name": "fake_tenant_name"
-                    },
-                    "https_insecure": True,
-                    "https_cacert": "fake_cacert",
-                    "profiler_hmac_key": "fake_hmac_key"
-                }
-            },
-            name="from_env"
-        )
-
-    @mock.patch.dict(os.environ, {"OS_AUTH_URL": "fake_auth_url",
-                                  "OS_USERNAME": "fake_username",
-                                  "OS_PASSWORD": "fake_password",
-                                  "OS_TENANT_NAME": "fake_tenant_name",
-                                  "OS_REGION_NAME": "fake_region_name",
-                                  "OS_ENDPOINT_TYPE": "fake_endpoint_typeURL",
-                                  "OS_PROJECT_DOMAIN_NAME": "fake_pdn",
-                                  "OS_USER_DOMAIN_NAME": "fake_udn",
-                                  "OS_ENDPOINT": "fake_endpoint",
-                                  "OS_INSECURE": "True",
-                                  "OS_CACERT": "fake_cacert",
-                                  "RALLY_DEPLOYMENT": "fake_deployment_id",
-                                  "OSPROFILER_HMAC_KEY": "fake_hmac_key"})
-    @mock.patch("rally.cli.commands.deployment.DeploymentCommands.list")
-    def test_createfromenv_keystonev3(self, mock_list):
-        self.deployment.create(self.fake_api, "from_env", True)
-        self.fake_api.deployment.create.assert_called_once_with(
-            config={
-                "openstack": {
-                    "auth_url": "fake_auth_url",
-                    "region_name": "fake_region_name",
-                    "endpoint_type": "fake_endpoint_type",
-                    "endpoint": "fake_endpoint",
-                    "admin": {
-                        "username": "fake_username",
-                        "password": "fake_password",
-                        "user_domain_name": "fake_udn",
-                        "project_domain_name": "fake_pdn",
-                        "project_name": "fake_tenant_name"
-                    },
-                    "https_insecure": True,
-                    "https_cacert": "fake_cacert",
-                    "profiler_hmac_key": "fake_hmac_key"
-                }
-            },
+            config={"auth_url": "http://fake"},
             name="from_env"
         )
 
@@ -294,10 +231,14 @@ class DeploymentCommandsTestCase(test.TestCase):
         with mock.patch("rally.cli.commands.deployment.open", mock.mock_open(),
                         create=True) as mock_file:
             self.deployment.use(self.fake_api, deployment_id)
-            self.assertEqual(2, mock_path_exists.call_count)
-            mock_update_env_file.assert_called_once_with(os.path.expanduser(
-                "~/.rally/globals"),
-                "RALLY_DEPLOYMENT", "%s\n" % deployment_id)
+            self.assertEqual(3, mock_path_exists.call_count)
+            mock_update_env_file.assert_has_calls([
+                mock.call(os.path.expanduser("~/.rally/globals"),
+                          "RALLY_DEPLOYMENT", "%s\n" % deployment_id),
+                mock.call(os.path.expanduser("~/.rally/globals"),
+                          "RALLY_ENV", "%s\n" % deployment_id),
+            ])
+
             mock_file.return_value.write.assert_any_call(
                 "export OS_ENDPOINT='fake_endpoint'\n")
             mock_file.return_value.write.assert_any_call(
@@ -336,10 +277,13 @@ class DeploymentCommandsTestCase(test.TestCase):
         with mock.patch("rally.cli.commands.deployment.open", mock.mock_open(),
                         create=True) as mock_file:
             self.deployment.use(self.fake_api, deployment_id)
-            self.assertEqual(2, mock_path_exists.call_count)
-            mock_update_env_file.assert_called_once_with(os.path.expanduser(
-                "~/.rally/globals"),
-                "RALLY_DEPLOYMENT", "%s\n" % deployment_id)
+            self.assertEqual(3, mock_path_exists.call_count)
+            mock_update_env_file.assert_has_calls([
+                mock.call(os.path.expanduser("~/.rally/globals"),
+                          "RALLY_DEPLOYMENT", "%s\n" % deployment_id),
+                mock.call(os.path.expanduser("~/.rally/globals"),
+                          "RALLY_ENV", "%s\n" % deployment_id)
+            ])
             mock_file.return_value.write.assert_any_call(
                 "export OS_ENDPOINT='fake_endpoint'\n")
             mock_file.return_value.write.assert_any_call(
@@ -372,14 +316,17 @@ class DeploymentCommandsTestCase(test.TestCase):
         self.assertIsNone(status)
         self.fake_api.deployment.get.assert_called_once_with(
             deployment="fake_name")
-        mock_update_globals_file.assert_called_once_with(
-            envutils.ENV_DEPLOYMENT, "fake_uuid")
+        mock_update_globals_file.assert_has_calls([
+            mock.call(envutils.ENV_DEPLOYMENT, "fake_uuid"),
+            mock.call(envutils.ENV_ENV, "fake_uuid")
+        ])
         mock__update_openrc_deployment_file.assert_called_once_with(
             "fake_uuid", "foo_admin")
 
     def test_deployment_not_found(self):
         deployment_id = "e87e4dca-b515-4477-888d-5f6103f13b42"
-        exc = exceptions.DeploymentNotFound(deployment=deployment_id)
+        exc = exceptions.DBRecordNotFound(criteria="uuid: %s" % deployment_id,
+                                          table="deployments")
         self.fake_api.deployment.get.side_effect = exc
         self.assertEqual(1, self.deployment.use(self.fake_api, deployment_id))
 
